@@ -1,3 +1,4 @@
+"""Vedirect init logger entry."""
 import logging
 # Version of realpython-reader package
 __author__ = "Janne Kario, Eli Serra"
@@ -5,23 +6,25 @@ __copyright__ = "Copyright 2015, Janne Kario"
 __deprecated__ = False
 __license__ = "MIT"
 __status__ = "Production"
-__version__ = "1.2.2"
+__version__ = "1.2.4"
 
 
 class AppFilter(logging.Filter):
     """
-    Class used to add a custom entry into the logger
+    Class used to add a custom entry into the logger.
     """
 
     def filter(self, record):
-        """Logger app version"""
+        """Logger app version."""
         record.app_version = "vedirect-%s" % __version__
         return True
 
 
 def configure_logging(debug: bool = False):
     """
-    Prepare log folder in current home directory
+    Prepare log folder in current home directory.
+
+    Format logger output
     :param debug: If true, set the lof level to debug
     """
     logger = logging.getLogger("vedirect")
