@@ -20,7 +20,8 @@ from ve_utils.utype import UType as Ut
 from vedirect_m8.sertest import SerialTestHelper
 from vedirect_m8.vedirect import Vedirect
 from vedirect_m8.serconnect import SerialConnection
-from vedirect_m8.exceptions import InputReadException, TimeoutException, VedirectException, SettingInvalidException
+from vedirect_m8.exceptions import InputReadException, TimeoutException
+from vedirect_m8.exceptions import VedirectException, SettingInvalidException
 
 __author__ = "Eli Serra"
 __copyright__ = "Copyright 2020, Eli Serra"
@@ -52,6 +53,7 @@ class VedirectController(Vedirect):
                  baud: int = 19200,
                  timeout: int or float = 0,
                  source_name: str = 'VedirectController',
+                 wait_connection: bool = True
                  ):
         """
         Constructor of VedirectController class.
@@ -66,27 +68,29 @@ class VedirectController(Vedirect):
         :param baud: Baud rate such as 9600 or 115200 etc.
         :param timeout: Set a read timeout value in seconds,
         :param source_name: This is used in logger to identify the source of call.
+        :param wait_connection: bool: Used to wait for connection on new serial port at start.
         :return: Nothing
         """
+        self._wait_connection = Ut.str_to_bool(wait_connection)
+        self._ser_test = None
+        self.init_serial_test(serial_test)
         Vedirect.__init__(self,
                           serial_port=serial_port,
                           baud=baud,
                           timeout=timeout,
                           source_name=source_name)
-        self._ser_test = None
-        self.init_serial_test(serial_test)
 
     def has_serial_test(self) -> bool:
-        """ Test if is valid serial test helper """
+        """Test if is valid serial test helper."""
         return isinstance(self._ser_test, SerialTestHelper)\
             and self._ser_test.has_serial_tests()
 
     def is_ready(self) -> bool:
-        """Test if class Vedirect is ready"""
+        """Test if class Vedirect is ready."""
         return self.is_serial_ready() and self.has_serial_test()
 
     def is_ready_to_search_ports(self) -> bool:
-        """Test if class Vedirect is ready"""
+        """Test if class Vedirect is ready."""
         return self.has_serial_com() and self.has_serial_test()
 
     def init_serial_test(self, serial_test: dict) -> bool:
@@ -147,34 +151,61 @@ class VedirectController(Vedirect):
 
         .. raises:: SettingInvalidException, VedirectException
         """
+        result = False
         try:
-            return self.init_serial_connection(serial_port=serial_port,
-                                               baud=baud,
-                                               timeout=timeout,
-                                               source_name=source_name
-                                               )
+            result = self.init_serial_connection(serial_port=serial_port,
+                                                 baud=baud,
+                                                 timeout=timeout,
+                                                 source_name=source_name
+                                                 )
         except VedirectException as ex:
-            if self.wait_or_search_serial_connection(timeout=wait_timeout, exception=ex):
-                return True
-        return False
+            if self._wait_connection is True\
+                    and self.wait_or_search_serial_connection(
+                    timeout=wait_timeout,
+                    exception=ex
+                    ):
+                result = True
+            else:
+                raise VedirectException from VedirectException
+        return result
 
     def read_data_to_test(self) -> dict:
-        """
-        Return decoded Vedirect blocks from serial to identify the right serial port.
-        """
-        res = None
+        """Return decoded Vedirect blocks from serial to identify the right serial port."""
+        result = None
         if self.is_ready():
             try:
-                res = dict()
-                data = self.read_data_single(timeout=1)
-                if Ut.is_dict(data, not_null=True):
-                    res.update(data)
+                result = dict()
+                for i in range(3):
+                    data = self.read_data_single(timeout=1)
+                    if Ut.is_dict(data, not_null=True):
+                        result.update(data)
+                    time.sleep(0.2)
             except Exception as ex:
                 logger.debug(
                     '[VeDirect] Unable to read serial data to test'
-                    'ex : %s' % ex
+                    'ex : %s',
+                    ex
                 )
-        return res
+        return result
+
+    def _test_serial_port(self, port: str) -> bool:
+        """Attempt serial connection on specified port."""
+        result = False
+        if SerialConnection.is_serial_port(port):
+            if self._com.connect(**{"serial_port": port, 'timeout': 0}):
+                time.sleep(0.5)
+                data = self.read_data_to_test()
+                if self._ser_test.run_serial_tests(data):
+                    self._com.ser.timeout = self._com.get_timeout()
+                    logger.info(
+                        "[VeDirect::_test_serial_port] "
+                        "New connection established to serial port %s. ",
+                        port
+                    )
+                    result = True
+                else:
+                    self._com.ser.close()
+        return result
 
     def test_serial_ports(self, ports: list) -> bool:
         """
@@ -186,34 +217,21 @@ class VedirectController(Vedirect):
         and reads data from it. It then passes this data into
         the SerialTestHelper class which runs some basic tests
         on the data returned by the serial connection.
+
+        Raise:
+            - VedirectException
         :param self: Reference the class instance
-        :param ports:list: Specify the serial ports to test
+        :param ports: list: Specify the serial ports to test
         :return: True if the serial port is open and
                  connected to a device that returns valid data
-
-        .. raises:: VedirectException,
-        :doc-author: Trelent
         """
+        result = False
         if self.is_ready_to_search_ports():
             if Ut.is_list(ports, not_null=True):
                 for port in ports:
-                    if SerialConnection.is_serial_port(port):
-
-                        if self._com.connect(**{"serial_port": port, 'timeout': 0}):
-                            time.sleep(0.5)
-                            data = self.read_data_to_test()
-                            if self._ser_test.run_serial_tests(data):
-                                self._com.ser.timeout = self._com._timeout
-                                logger.info(
-                                    "[VeDirect::test_serial_ports] "
-                                    "New connection established to serial port %s. " %
-                                    port
-                                )
-                                return True
-                            else:
-                                self._com.ser.close()
-
-                return False
+                    if self._test_serial_port(port):
+                        result = True
+                        break
         else:
             raise VedirectException(
                 "[VeDirect::test_serial_ports] "
@@ -221,6 +239,7 @@ class VedirectController(Vedirect):
                 "SerialConnection and/or SerialTestHelper, "
                 "are not ready."
             )
+        return result
 
     def search_serial_port(self) -> bool:
         """Search the serial port from serial tests."""
@@ -259,10 +278,11 @@ class VedirectController(Vedirect):
             logger.info(
                 "[VeDirect::wait_or_search_serial_connection] "
                 "Lost serial connection, attempting to reconnect. "
-                "reconnection timeout is set to %ss" % timeout
+                "reconnection timeout is set to %ss",
+                timeout
             )
-            bc, now, tim = True, time.time(), 0
-            while bc:
+            run, now, tim = True, time.time(), 0
+            while run:
                 tim = time.time()
                 if self.search_serial_port():
                     return True
@@ -271,10 +291,10 @@ class VedirectController(Vedirect):
                     raise TimeoutException(
                         "[VeDirect::wait_or_search_serial_connection] "
                         "Unable to connect to any serial item. "
-                        "Timeout error : %s. Exception : %s" % 
+                        "Timeout error : %s. Exception : %s" %
                         (timeout, exception)
                     )
-                
+
                 time.sleep(2.5)
         raise VedirectException(
             "[VeDirect::wait_or_search_serial_connection] "
@@ -290,7 +310,7 @@ class VedirectController(Vedirect):
                            ) -> dict or None:
         """
         Read data from the serial port and returns it to a callback function.
-        
+
         :param self: Reference the class instance
         :param callback_func:function: Pass a function to the read_data_callback function
         :param timeout:int=60: Set the timeout for the read_data_callback function
@@ -299,10 +319,10 @@ class VedirectController(Vedirect):
         :return: A dictionary
         :doc-author: Trelent
         """
-        bc, now, tim, i = True, time.time(), 0, 0
+        run, now, tim, i = True, time.time(), 0, 0
         packet = None
         if self.is_ready():
-            while bc:
+            while run:
                 tim = time.time()
                 try:
                     packet = self.get_serial_packet()
@@ -320,8 +340,8 @@ class VedirectController(Vedirect):
                         "Serial reader success: "
                         "packet: %s -- "
                         "state: %s -- "
-                        "bytes_sum: %s " % 
-                        (packet, self.state, self.bytes_sum)
+                        "bytes_sum: %s ",
+                        packet, self.state, self.bytes_sum
                     )
                     callback_func(packet)
                     now = tim
@@ -339,5 +359,5 @@ class VedirectController(Vedirect):
                 '[VeDirect::read_data_callback] '
                 'Unable to read serial data. '
                 'Not connected to serial port...')
-        
+
         callback_func(None)
